eprllib.Utils.env_config_utils — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Utils.env_config_utils

## Utilities for the environment configuration

Work in progress…

Functions

`EP_API_add_path`([version, path]) | This method add the EnergyPlus Python API to the system path.
`continuous_action_space`() | This method construct the action space of the environment.
`discrete_action_space`([n]) | This method construct the action space of the environment.
`env_config_to_dict`(MyEnvConfig) | Convert an EnvConfig object into a dict before to be used in the env_config parameter of RLlib environment config.
`env_config_validation`(MyEnvConfig) | Validate the EnvConfig object before to be used in the env_config parameter of RLlib environment config.
`from_json`(path) | Convert a json file into an EnvConfig object before to be used in the env_config parameter of RLlib environment config.
`to_json`(MyEnvConfig[, output_path]) | Convert an EnvConfig object into a json string before to be used in the env_config parameter of RLlib environment config.